from eskmo.base.mvtype import *
from eskmo.const.event import *
from eskmo.const.skcom import *

class AssetClass:
    TW_STOCK: int
    TW_ODD_LOTS: int

class APIMode:
    CONSOLE: int
    APPLICATION: int
    LOCAL_GRPC: int
    LOCAL_ZMQ: int
    LOCAL_SOCKETIO: int

class OrderExchange:
    TSE_AND_TPEX = SKO_ORDER_LISTED_AND_OTC
    ESM = SKO_ORDER_ESM

class OrderPeriod:
    INTRA_DAY = SKO_ORDER_INTRADAY
    AFTER_HOURS = SKO_ORDER_AFTER_HOURS

class OrderFlag:
    CASH = SKO_ORDER_CASH
    MARGIN = SKO_ORDER_MARGIN
    SHORT = SKO_ORDER_SHORT
    DAYTRADE_SHORT = SKO_ORDER_NAKED_SHORT

class OrderAction:
    BUY = SKO_ORDER_BUY
    SELL = SKO_ORDER_SELL

class OrderPriceType:
    MARKET = SKO_ORDER_TYPE_MARKET
    LIMIT = SKO_ORDER_TYPE_LIMIT

class OrderType:
    ROD = SKO_ORDER_ROD
    IOC = SKO_ORDER_IOC
    FOK = SKO_ORDER_FOK

class Order:
    EXCHANGE = OrderExchange
    PERIOD = OrderPeriod
    FLAG = OrderFlag
    ACTION = OrderAction
    PRICE = OrderPriceType
    TRADE = OrderType

class SmartOrderFlag:
    CASH = SKO_MIT_CASH
    MARGIN = SKO_MIT_MARGIN
    SHORT = SKO_MIT_SHORT
    DAYTRADE_SHORT = SKO_MIT_NAKED_SHORT

class SmartOrderOrderType:
    ROD = SKO_MIT_ROD
    IOC = SKO_MIT_IOC
    FOK = SKO_MIT_FOK

class SmartOrderTriggerDir:
    GTE = SKO_MIT_GTE
    LTE = SKO_MIT_LTE

class SmartOrderLongEndBy:
    TRIGGERED = SKO_MIT_LONG_END_BY_TRIGGERED
    FULFILLED = SKO_MIT_LONG_END_BY_FULFILLED

class MITOrder:
    ORDER_FLAG = SmartOrderFlag
    PRICE_TYPE = OrderPriceType
    ORDER_TYPE = SmartOrderOrderType
    TRIGGER_DIR = SmartOrderTriggerDir
    ACTION = OrderAction
    LONG_END_BY = SmartOrderLongEndBy

class SmartOrder:
    MIT = MITOrder

class When:
    START = WHEN_START
    SUCCESS = WHEN_SUCCESS
    FAIL = WHEN_FAIL

class Market:
    STOCK = STOCK
    ODD_LOTS = ODD_LOTS

class Data:
    MESSAGES = E_MESSAGES
    ERRORS = E_ERRORS

class Channel:
    QUOTE = QUOTE
    TICK = TICK
    BEST5 = BEST5
    ERRORS = E_ERRORS

class SimulateType:
    ENABLED = SK_SIMULATE_ENABLED
    DISABLED = SK_SIMULATE_DISABLED

class DayTradeType:
    DISABLED = SK_DAY_TRADE_DISABLED
    BUY_THEN_SELL_ONLY = SK_DAY_TRADE_BUY_FIRST_ONLY
    ENABLED = SK_DAY_TRADE_ENABLED

class MarginPurchaseFlag:
    ENABLED = SK_MARGIN_FINANCING_FLAG_ENABLED
    DISABLED = SK_MARGIN_FINANCING_FLAG_DISABLED
    UNELGIBLE = SK_MARGIN_FINANCING_FLAG_UNELIGIBLE

class MarginPurchaseLimit:
    EMPTY = SK_MARGIN_FINANCING_LIMIT_EMPTY
    NONE = SK_MARGIN_FINANCING_LIMIT_NONE

class ShortSaleFlag:
    ENABLED = SK_MARGIN_SHORT_SELLING_FLAG_ENABLED
    DISABLED = SK_MARGIN_SHORT_SELLING_FLAG_DISABLED
    UNELGIBLE = SK_MARGIN_SHORT_SELLING_FLAG_UNELIGIBLE

class ShortSaleLimit:
    EMPTY = SK_MARGIN_FINANCING_LIMIT_EMPTY
    NONE = SK_MARGIN_FINANCING_LIMIT_NONE

class DayTradeFlag:
    ENABLED = SK_MARGIN_DAY_TRADE_FLAG_ENABLED
    DISABLED = SK_MARGIN_DAY_TRADE_FLAG_DISABLED

class DownGradeFlag:
    NORMAL = SK_MARGIN_DOWN_GRADE_FLAG_NORMAL
    DOWN = SK_MARGIN_DOWN_GRADE_FLAG_DOWN
    UP = SK_MARGIN_DOWN_GRADE_FLAG_UP

class FlatShortFlag:
    ENABLED = SK_MARGIN_FLAT_POSITION_SHORT_SELL_FLAG_ENABLED
    DISABLED = SK_MARGIN_FLAT_POSITION_SHORT_SELL_FLAG_DISABLED

class FullCashDeliveryFlag:
    ENABLED = SK_MARGIN_FULL_SETTLEMENT_ENABLED
    DISABLED = SK_MARGIN_FULL_SETTLEMENT_DISABLED

class AlertingFlag:
    ENABLED = SK_MARGIN_WARNING_FLAG_ENABLED
    DISABLED = SK_MARGIN_WARNING_FLAG_DISABLED

class DispositionFlag:
    DISABLED = SK_MARGIN_DISPOSITION_STOCK_DISABLED
    ENABLED = SK_MARGIN_DISPOSITION_STOCK_ENABLED
    ENABLED_AGAIN = SK_MARGIN_DISPOSITION_STOCK_ENABLED_AGAIN
    ENABLED_FLEXIBLE = SK_MARGIN_DISPOSITION_STOCK_ENABLED_FLEXIBLE

class AttentionFlag:
    DISABLED = SK_MARGIN_WATCH_STOCK_FLAG_DISABLED
    ENABLED = SK_MARGIN_WATCH_STOCK_FLAG_ENABLED

class RestrictedFlag:
    DISABLED = SK_MARGIN_RESTRICTED_STOCK_FLAG_DISABLED
    ENABLED = SK_MARGIN_RESTRICTED_STOCK_FLAG_ENABLED

class SpecificAbnormallyFlag:
    DISABLED = SK_MARGIN_SPECIAL_ABNORMAL_FLAG_DISABLED
    ENABLED = SK_MARGIN_SPECIAL_ABNORMAL_FLAG_ENABLED

class UnusallyRecommendedFlag:
    DISABLED = SK_MARGIN_ABNORMAL_PROMOTION_FLAG_DISABLED
    ENABLED = SK_MARGIN_ABNORMAL_PROMOTION_FLAG_ENABLED

class SymbolConsts:
    SIMULATE = SimulateType
    DAY_TRADE = DayTradeFlag
    DAY_TRADE_TYPE = DayTradeType
    MARGIN_PURCHASE = MarginPurchaseFlag
    MARGIN_PURCHASE_LIMIT = MarginPurchaseLimit
    SHORT_SALE = ShortSaleFlag
    SHORT_SALE_LIMIT = ShortSaleLimit
    DOWN_GRADE = DownGradeFlag
    FLAT_SHORT = FlatShortFlag
    FULLCASH_DELIVERY = FullCashDeliveryFlag
    ALERTING = AlertingFlag
    DISPOSITION = DispositionFlag
    ATTENTION = AttentionFlag
    RESTRICTED = RestrictedFlag
    UNUSALLY_RECOMMENDED = UnusallyRecommendedFlag
    SPECIFIC_ABNORMALLY = SpecificAbnormallyFlag

class PnLTypes:
    UNREALIZED = SKO_PNL_UNREALIZED
    REALIZED = SKO_PNL_REALIZED
    DAY_TRADE = SKO_PNL_DAY_TRADE

class PnLFormats:
    SUMMARY = SKO_PNL_FORMAT_SUMMARY
    DETAILED = SKO_PNL_FORMAT_DETAILED
    TOTAL = SKO_PNL_FORMAT_TOTAL_INVESTMENT
    BY_STOCK_NO = SKO_PNL_FORMAT_SUMMARY_BY_STOCK_NO

class PnLTradeTypes:
    TYPE = PnLTypes
    FORMAT = PnLFormats

class PnLConsts:
    TYPE = PnLTypes
    FORMAT = PnLFormats
    TRADE_TYPE = PnLTradeTypes

class TradeTypes:
    STOCK = SKO_TRADE_STOCK
    MARGIN_AGENT = SKO_TRADE_MARGIN_BORKER
    SHORT_MARGIN_AGENT = SKO_TRADE_SHORT_MARGIN_BORKER
    MARGIN = SKO_TRADE_MARGIN
    SHORT_MARGIN = SKO_TRADE_SHORT_MARGIN
    STOCK_DAYTRADE = SKO_TRADE_STOCK_DAYTRADE
    SLB = SKO_TRADE_SLB
    NAKED_SHORT = SKO_TEADE_NAKED_SHORT

class TradeConsts:
    TYPE = TradeTypes

class EskmoConst:
    ASSET = AssetClass
    API_MODE = APIMode
    SYMBOL = SymbolConsts
    MARKET = Market
    ORDER = Order
    TRADE = TradeConsts
    SMART_ORDER = SmartOrder
    WHEN = When
    DATA = Data
    CHANNEL = Channel
    PNL = PnLConsts
